@@ -922,12 +922,7 @@ def test_update_database(mocker: MockerFixture) -> None:
     update_resource = mocker.patch.object(client, "update_resource")
 
     client.update_database(1, database_name="my_other_db")
-    update_resource.assert_called_with(
-        "database",
-        1,
-        {"override_columns": "true"},
-        database_name="my_other_db",
-    )
+    update_resource.assert_called_with("database", 1, database_name="my_other_db")
 
 
 def test_get_dataset(mocker: MockerFixture) -> None:
@@ -981,7 +976,9 @@ def test_update_dataset(mocker: MockerFixture) -> None:
     update_resource = mocker.patch.object(client, "update_resource")
 
     client.update_dataset(1, dataset_name="my_other_db")
-    update_resource.assert_called_with("dataset", 1, dataset_name="my_other_db")
+    update_resource.assert_called_with(
+        "dataset", 1, {"override_columns": "true"}, dataset_name="my_other_db",
+    )
 
 
 def test_get_chart(mocker: MockerFixture) -> None:
@@ -1215,6 +1212,7 @@ def test_export_users(requests_mock: Mocker) -> None:
     """
     Test ``export_users``.
     """
+    requests_mock.get("https://superset.example.org/users/list/")
     requests_mock.get(
         "https://superset.example.org/users/list/?psize_UserDBModelView=100&page_UserDBModelView=0",
         text="""
@@ -1306,6 +1304,78 @@ def test_export_users(requests_mock: Mocker) -> None:
     ]
 
 
+def test_export_users_preset(requests_mock: Mocker) -> None:
+    """
+    Test ``export_users``.
+    """
+    requests_mock.get("https://superset.example.org/users/list/", status_code=404)
+    requests_mock.get(
+        "https://manage.app.preset.io/api/v1/teams/",
+        json={
+            "payload": [{"name": "team1"}],
+        },
+    )
+    requests_mock.get(
+        "https://manage.app.preset.io/api/v1/teams/team1/workspaces/",
+        json={
+            "payload": [{"id": 1, "hostname": "superset.example.org"}],
+        },
+    )
+    requests_mock.get(
+        "https://manage.app.preset.io/api/v1/teams/team1/workspaces/1/memberships",
+        json={
+            "payload": [
+                {
+                    "user": {
+                        "username": "adoe",
+                        "first_name": "Alice",
+                        "last_name": "Doe",
+                        "email": "adoe@example.com",
+                    },
+                },
+                {
+                    "user": {
+                        "username": "bdoe",
+                        "first_name": "Bob",
+                        "last_name": "Doe",
+                        "email": "bdoe@example.com",
+                    },
+                },
+            ],
+        },
+    )
+    requests_mock.get(
+        "https://superset.example.org/roles/add",
+        text="""
+<select id="user">
+    <option value="1">Alice Doe</option>
+    <option value="2">Bob Doe</option>
+</select>
+    """,
+    )
+
+    auth = Auth()
+    client = SupersetClient("https://superset.example.org/", auth)
+    assert list(client.export_users()) == [
+        {
+            "id": 1,
+            "first_name": "Alice",
+            "last_name": "Doe",
+            "username": "adoe",
+            "email": "adoe@example.com",
+            "role": [],
+        },
+        {
+            "id": 2,
+            "first_name": "Bob",
+            "last_name": "Doe",
+            "username": "bdoe",
+            "email": "bdoe@example.com",
+            "role": [],
+        },
+    ]
+
+
 def test_export_rls(requests_mock: Mocker) -> None:
     """
     Test ``export_rls``.
